@@ -6,9 +6,9 @@ Type annotations for machinelearning service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_machinelearning.type_defs import AddTagsInputTypeDef
+    from mypy_boto3_machinelearning.type_defs import AddTagsInputRequestTypeDef
 
-    data: AddTagsInputTypeDef = {...}
+    data: AddTagsInputRequestTypeDef = {...}
     ```
 """
 import sys
@@ -39,60 +39,60 @@ else:
 
 
 __all__ = (
-    "AddTagsInputTypeDef",
-    "AddTagsOutputResponseTypeDef",
+    "AddTagsInputRequestTypeDef",
+    "AddTagsOutputTypeDef",
     "BatchPredictionTypeDef",
-    "CreateBatchPredictionInputTypeDef",
-    "CreateBatchPredictionOutputResponseTypeDef",
-    "CreateDataSourceFromRDSInputTypeDef",
-    "CreateDataSourceFromRDSOutputResponseTypeDef",
-    "CreateDataSourceFromRedshiftInputTypeDef",
-    "CreateDataSourceFromRedshiftOutputResponseTypeDef",
-    "CreateDataSourceFromS3InputTypeDef",
-    "CreateDataSourceFromS3OutputResponseTypeDef",
-    "CreateEvaluationInputTypeDef",
-    "CreateEvaluationOutputResponseTypeDef",
-    "CreateMLModelInputTypeDef",
-    "CreateMLModelOutputResponseTypeDef",
-    "CreateRealtimeEndpointInputTypeDef",
-    "CreateRealtimeEndpointOutputResponseTypeDef",
+    "CreateBatchPredictionInputRequestTypeDef",
+    "CreateBatchPredictionOutputTypeDef",
+    "CreateDataSourceFromRDSInputRequestTypeDef",
+    "CreateDataSourceFromRDSOutputTypeDef",
+    "CreateDataSourceFromRedshiftInputRequestTypeDef",
+    "CreateDataSourceFromRedshiftOutputTypeDef",
+    "CreateDataSourceFromS3InputRequestTypeDef",
+    "CreateDataSourceFromS3OutputTypeDef",
+    "CreateEvaluationInputRequestTypeDef",
+    "CreateEvaluationOutputTypeDef",
+    "CreateMLModelInputRequestTypeDef",
+    "CreateMLModelOutputTypeDef",
+    "CreateRealtimeEndpointInputRequestTypeDef",
+    "CreateRealtimeEndpointOutputTypeDef",
     "DataSourceTypeDef",
-    "DeleteBatchPredictionInputTypeDef",
-    "DeleteBatchPredictionOutputResponseTypeDef",
-    "DeleteDataSourceInputTypeDef",
-    "DeleteDataSourceOutputResponseTypeDef",
-    "DeleteEvaluationInputTypeDef",
-    "DeleteEvaluationOutputResponseTypeDef",
-    "DeleteMLModelInputTypeDef",
-    "DeleteMLModelOutputResponseTypeDef",
-    "DeleteRealtimeEndpointInputTypeDef",
-    "DeleteRealtimeEndpointOutputResponseTypeDef",
-    "DeleteTagsInputTypeDef",
-    "DeleteTagsOutputResponseTypeDef",
-    "DescribeBatchPredictionsInputTypeDef",
-    "DescribeBatchPredictionsOutputResponseTypeDef",
-    "DescribeDataSourcesInputTypeDef",
-    "DescribeDataSourcesOutputResponseTypeDef",
-    "DescribeEvaluationsInputTypeDef",
-    "DescribeEvaluationsOutputResponseTypeDef",
-    "DescribeMLModelsInputTypeDef",
-    "DescribeMLModelsOutputResponseTypeDef",
-    "DescribeTagsInputTypeDef",
-    "DescribeTagsOutputResponseTypeDef",
+    "DeleteBatchPredictionInputRequestTypeDef",
+    "DeleteBatchPredictionOutputTypeDef",
+    "DeleteDataSourceInputRequestTypeDef",
+    "DeleteDataSourceOutputTypeDef",
+    "DeleteEvaluationInputRequestTypeDef",
+    "DeleteEvaluationOutputTypeDef",
+    "DeleteMLModelInputRequestTypeDef",
+    "DeleteMLModelOutputTypeDef",
+    "DeleteRealtimeEndpointInputRequestTypeDef",
+    "DeleteRealtimeEndpointOutputTypeDef",
+    "DeleteTagsInputRequestTypeDef",
+    "DeleteTagsOutputTypeDef",
+    "DescribeBatchPredictionsInputRequestTypeDef",
+    "DescribeBatchPredictionsOutputTypeDef",
+    "DescribeDataSourcesInputRequestTypeDef",
+    "DescribeDataSourcesOutputTypeDef",
+    "DescribeEvaluationsInputRequestTypeDef",
+    "DescribeEvaluationsOutputTypeDef",
+    "DescribeMLModelsInputRequestTypeDef",
+    "DescribeMLModelsOutputTypeDef",
+    "DescribeTagsInputRequestTypeDef",
+    "DescribeTagsOutputTypeDef",
     "EvaluationTypeDef",
-    "GetBatchPredictionInputTypeDef",
-    "GetBatchPredictionOutputResponseTypeDef",
-    "GetDataSourceInputTypeDef",
-    "GetDataSourceOutputResponseTypeDef",
-    "GetEvaluationInputTypeDef",
-    "GetEvaluationOutputResponseTypeDef",
-    "GetMLModelInputTypeDef",
-    "GetMLModelOutputResponseTypeDef",
+    "GetBatchPredictionInputRequestTypeDef",
+    "GetBatchPredictionOutputTypeDef",
+    "GetDataSourceInputRequestTypeDef",
+    "GetDataSourceOutputTypeDef",
+    "GetEvaluationInputRequestTypeDef",
+    "GetEvaluationOutputTypeDef",
+    "GetMLModelInputRequestTypeDef",
+    "GetMLModelOutputTypeDef",
     "MLModelTypeDef",
     "PaginatorConfigTypeDef",
     "PerformanceMetricsTypeDef",
-    "PredictInputTypeDef",
-    "PredictOutputResponseTypeDef",
+    "PredictInputRequestTypeDef",
+    "PredictOutputTypeDef",
     "PredictionTypeDef",
     "RDSDataSpecTypeDef",
     "RDSDatabaseCredentialsTypeDef",
@@ -106,19 +106,19 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "S3DataSpecTypeDef",
     "TagTypeDef",
-    "UpdateBatchPredictionInputTypeDef",
-    "UpdateBatchPredictionOutputResponseTypeDef",
-    "UpdateDataSourceInputTypeDef",
-    "UpdateDataSourceOutputResponseTypeDef",
-    "UpdateEvaluationInputTypeDef",
-    "UpdateEvaluationOutputResponseTypeDef",
-    "UpdateMLModelInputTypeDef",
-    "UpdateMLModelOutputResponseTypeDef",
+    "UpdateBatchPredictionInputRequestTypeDef",
+    "UpdateBatchPredictionOutputTypeDef",
+    "UpdateDataSourceInputRequestTypeDef",
+    "UpdateDataSourceOutputTypeDef",
+    "UpdateEvaluationInputRequestTypeDef",
+    "UpdateEvaluationOutputTypeDef",
+    "UpdateMLModelInputRequestTypeDef",
+    "UpdateMLModelOutputTypeDef",
     "WaiterConfigTypeDef",
 )
 
-AddTagsInputTypeDef = TypedDict(
-    "AddTagsInputTypeDef",
+AddTagsInputRequestTypeDef = TypedDict(
+    "AddTagsInputRequestTypeDef",
     {
         "Tags": List["TagTypeDef"],
         "ResourceId": str,
@@ -126,8 +126,8 @@ AddTagsInputTypeDef = TypedDict(
     },
 )
 
-AddTagsOutputResponseTypeDef = TypedDict(
-    "AddTagsOutputResponseTypeDef",
+AddTagsOutputTypeDef = TypedDict(
+    "AddTagsOutputTypeDef",
     {
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
@@ -158,8 +158,8 @@ BatchPredictionTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredCreateBatchPredictionInputTypeDef = TypedDict(
-    "_RequiredCreateBatchPredictionInputTypeDef",
+_RequiredCreateBatchPredictionInputRequestTypeDef = TypedDict(
+    "_RequiredCreateBatchPredictionInputRequestTypeDef",
     {
         "BatchPredictionId": str,
         "MLModelId": str,
@@ -167,8 +167,8 @@ _RequiredCreateBatchPredictionInputTypeDef = TypedDict(
         "OutputUri": str,
     },
 )
-_OptionalCreateBatchPredictionInputTypeDef = TypedDict(
-    "_OptionalCreateBatchPredictionInputTypeDef",
+_OptionalCreateBatchPredictionInputRequestTypeDef = TypedDict(
+    "_OptionalCreateBatchPredictionInputRequestTypeDef",
     {
         "BatchPredictionName": str,
     },
@@ -176,30 +176,31 @@ _OptionalCreateBatchPredictionInputTypeDef = TypedDict(
 )
 
 
-class CreateBatchPredictionInputTypeDef(
-    _RequiredCreateBatchPredictionInputTypeDef, _OptionalCreateBatchPredictionInputTypeDef
+class CreateBatchPredictionInputRequestTypeDef(
+    _RequiredCreateBatchPredictionInputRequestTypeDef,
+    _OptionalCreateBatchPredictionInputRequestTypeDef,
 ):
     pass
 
 
-CreateBatchPredictionOutputResponseTypeDef = TypedDict(
-    "CreateBatchPredictionOutputResponseTypeDef",
+CreateBatchPredictionOutputTypeDef = TypedDict(
+    "CreateBatchPredictionOutputTypeDef",
     {
         "BatchPredictionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateDataSourceFromRDSInputTypeDef = TypedDict(
-    "_RequiredCreateDataSourceFromRDSInputTypeDef",
+_RequiredCreateDataSourceFromRDSInputRequestTypeDef = TypedDict(
+    "_RequiredCreateDataSourceFromRDSInputRequestTypeDef",
     {
         "DataSourceId": str,
         "RDSData": "RDSDataSpecTypeDef",
         "RoleARN": str,
     },
 )
-_OptionalCreateDataSourceFromRDSInputTypeDef = TypedDict(
-    "_OptionalCreateDataSourceFromRDSInputTypeDef",
+_OptionalCreateDataSourceFromRDSInputRequestTypeDef = TypedDict(
+    "_OptionalCreateDataSourceFromRDSInputRequestTypeDef",
     {
         "DataSourceName": str,
         "ComputeStatistics": bool,
@@ -208,30 +209,31 @@ _OptionalCreateDataSourceFromRDSInputTypeDef = TypedDict(
 )
 
 
-class CreateDataSourceFromRDSInputTypeDef(
-    _RequiredCreateDataSourceFromRDSInputTypeDef, _OptionalCreateDataSourceFromRDSInputTypeDef
+class CreateDataSourceFromRDSInputRequestTypeDef(
+    _RequiredCreateDataSourceFromRDSInputRequestTypeDef,
+    _OptionalCreateDataSourceFromRDSInputRequestTypeDef,
 ):
     pass
 
 
-CreateDataSourceFromRDSOutputResponseTypeDef = TypedDict(
-    "CreateDataSourceFromRDSOutputResponseTypeDef",
+CreateDataSourceFromRDSOutputTypeDef = TypedDict(
+    "CreateDataSourceFromRDSOutputTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateDataSourceFromRedshiftInputTypeDef = TypedDict(
-    "_RequiredCreateDataSourceFromRedshiftInputTypeDef",
+_RequiredCreateDataSourceFromRedshiftInputRequestTypeDef = TypedDict(
+    "_RequiredCreateDataSourceFromRedshiftInputRequestTypeDef",
     {
         "DataSourceId": str,
         "DataSpec": "RedshiftDataSpecTypeDef",
         "RoleARN": str,
     },
 )
-_OptionalCreateDataSourceFromRedshiftInputTypeDef = TypedDict(
-    "_OptionalCreateDataSourceFromRedshiftInputTypeDef",
+_OptionalCreateDataSourceFromRedshiftInputRequestTypeDef = TypedDict(
+    "_OptionalCreateDataSourceFromRedshiftInputRequestTypeDef",
     {
         "DataSourceName": str,
         "ComputeStatistics": bool,
@@ -240,30 +242,30 @@ _OptionalCreateDataSourceFromRedshiftInputTypeDef = TypedDict(
 )
 
 
-class CreateDataSourceFromRedshiftInputTypeDef(
-    _RequiredCreateDataSourceFromRedshiftInputTypeDef,
-    _OptionalCreateDataSourceFromRedshiftInputTypeDef,
+class CreateDataSourceFromRedshiftInputRequestTypeDef(
+    _RequiredCreateDataSourceFromRedshiftInputRequestTypeDef,
+    _OptionalCreateDataSourceFromRedshiftInputRequestTypeDef,
 ):
     pass
 
 
-CreateDataSourceFromRedshiftOutputResponseTypeDef = TypedDict(
-    "CreateDataSourceFromRedshiftOutputResponseTypeDef",
+CreateDataSourceFromRedshiftOutputTypeDef = TypedDict(
+    "CreateDataSourceFromRedshiftOutputTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateDataSourceFromS3InputTypeDef = TypedDict(
-    "_RequiredCreateDataSourceFromS3InputTypeDef",
+_RequiredCreateDataSourceFromS3InputRequestTypeDef = TypedDict(
+    "_RequiredCreateDataSourceFromS3InputRequestTypeDef",
     {
         "DataSourceId": str,
         "DataSpec": "S3DataSpecTypeDef",
     },
 )
-_OptionalCreateDataSourceFromS3InputTypeDef = TypedDict(
-    "_OptionalCreateDataSourceFromS3InputTypeDef",
+_OptionalCreateDataSourceFromS3InputRequestTypeDef = TypedDict(
+    "_OptionalCreateDataSourceFromS3InputRequestTypeDef",
     {
         "DataSourceName": str,
         "ComputeStatistics": bool,
@@ -272,30 +274,31 @@ _OptionalCreateDataSourceFromS3InputTypeDef = TypedDict(
 )
 
 
-class CreateDataSourceFromS3InputTypeDef(
-    _RequiredCreateDataSourceFromS3InputTypeDef, _OptionalCreateDataSourceFromS3InputTypeDef
+class CreateDataSourceFromS3InputRequestTypeDef(
+    _RequiredCreateDataSourceFromS3InputRequestTypeDef,
+    _OptionalCreateDataSourceFromS3InputRequestTypeDef,
 ):
     pass
 
 
-CreateDataSourceFromS3OutputResponseTypeDef = TypedDict(
-    "CreateDataSourceFromS3OutputResponseTypeDef",
+CreateDataSourceFromS3OutputTypeDef = TypedDict(
+    "CreateDataSourceFromS3OutputTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateEvaluationInputTypeDef = TypedDict(
-    "_RequiredCreateEvaluationInputTypeDef",
+_RequiredCreateEvaluationInputRequestTypeDef = TypedDict(
+    "_RequiredCreateEvaluationInputRequestTypeDef",
     {
         "EvaluationId": str,
         "MLModelId": str,
         "EvaluationDataSourceId": str,
     },
 )
-_OptionalCreateEvaluationInputTypeDef = TypedDict(
-    "_OptionalCreateEvaluationInputTypeDef",
+_OptionalCreateEvaluationInputRequestTypeDef = TypedDict(
+    "_OptionalCreateEvaluationInputRequestTypeDef",
     {
         "EvaluationName": str,
     },
@@ -303,30 +306,30 @@ _OptionalCreateEvaluationInputTypeDef = TypedDict(
 )
 
 
-class CreateEvaluationInputTypeDef(
-    _RequiredCreateEvaluationInputTypeDef, _OptionalCreateEvaluationInputTypeDef
+class CreateEvaluationInputRequestTypeDef(
+    _RequiredCreateEvaluationInputRequestTypeDef, _OptionalCreateEvaluationInputRequestTypeDef
 ):
     pass
 
 
-CreateEvaluationOutputResponseTypeDef = TypedDict(
-    "CreateEvaluationOutputResponseTypeDef",
+CreateEvaluationOutputTypeDef = TypedDict(
+    "CreateEvaluationOutputTypeDef",
     {
         "EvaluationId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredCreateMLModelInputTypeDef = TypedDict(
-    "_RequiredCreateMLModelInputTypeDef",
+_RequiredCreateMLModelInputRequestTypeDef = TypedDict(
+    "_RequiredCreateMLModelInputRequestTypeDef",
     {
         "MLModelId": str,
         "MLModelType": MLModelTypeType,
         "TrainingDataSourceId": str,
     },
 )
-_OptionalCreateMLModelInputTypeDef = TypedDict(
-    "_OptionalCreateMLModelInputTypeDef",
+_OptionalCreateMLModelInputRequestTypeDef = TypedDict(
+    "_OptionalCreateMLModelInputRequestTypeDef",
     {
         "MLModelName": str,
         "Parameters": Dict[str, str],
@@ -337,29 +340,29 @@ _OptionalCreateMLModelInputTypeDef = TypedDict(
 )
 
 
-class CreateMLModelInputTypeDef(
-    _RequiredCreateMLModelInputTypeDef, _OptionalCreateMLModelInputTypeDef
+class CreateMLModelInputRequestTypeDef(
+    _RequiredCreateMLModelInputRequestTypeDef, _OptionalCreateMLModelInputRequestTypeDef
 ):
     pass
 
 
-CreateMLModelOutputResponseTypeDef = TypedDict(
-    "CreateMLModelOutputResponseTypeDef",
+CreateMLModelOutputTypeDef = TypedDict(
+    "CreateMLModelOutputTypeDef",
     {
         "MLModelId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateRealtimeEndpointInputTypeDef = TypedDict(
-    "CreateRealtimeEndpointInputTypeDef",
+CreateRealtimeEndpointInputRequestTypeDef = TypedDict(
+    "CreateRealtimeEndpointInputRequestTypeDef",
     {
         "MLModelId": str,
     },
 )
 
-CreateRealtimeEndpointOutputResponseTypeDef = TypedDict(
-    "CreateRealtimeEndpointOutputResponseTypeDef",
+CreateRealtimeEndpointOutputTypeDef = TypedDict(
+    "CreateRealtimeEndpointOutputTypeDef",
     {
         "MLModelId": str,
         "RealtimeEndpointInfo": "RealtimeEndpointInfoTypeDef",
@@ -392,75 +395,75 @@ DataSourceTypeDef = TypedDict(
     total=False,
 )
 
-DeleteBatchPredictionInputTypeDef = TypedDict(
-    "DeleteBatchPredictionInputTypeDef",
+DeleteBatchPredictionInputRequestTypeDef = TypedDict(
+    "DeleteBatchPredictionInputRequestTypeDef",
     {
         "BatchPredictionId": str,
     },
 )
 
-DeleteBatchPredictionOutputResponseTypeDef = TypedDict(
-    "DeleteBatchPredictionOutputResponseTypeDef",
+DeleteBatchPredictionOutputTypeDef = TypedDict(
+    "DeleteBatchPredictionOutputTypeDef",
     {
         "BatchPredictionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteDataSourceInputTypeDef = TypedDict(
-    "DeleteDataSourceInputTypeDef",
+DeleteDataSourceInputRequestTypeDef = TypedDict(
+    "DeleteDataSourceInputRequestTypeDef",
     {
         "DataSourceId": str,
     },
 )
 
-DeleteDataSourceOutputResponseTypeDef = TypedDict(
-    "DeleteDataSourceOutputResponseTypeDef",
+DeleteDataSourceOutputTypeDef = TypedDict(
+    "DeleteDataSourceOutputTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteEvaluationInputTypeDef = TypedDict(
-    "DeleteEvaluationInputTypeDef",
+DeleteEvaluationInputRequestTypeDef = TypedDict(
+    "DeleteEvaluationInputRequestTypeDef",
     {
         "EvaluationId": str,
     },
 )
 
-DeleteEvaluationOutputResponseTypeDef = TypedDict(
-    "DeleteEvaluationOutputResponseTypeDef",
+DeleteEvaluationOutputTypeDef = TypedDict(
+    "DeleteEvaluationOutputTypeDef",
     {
         "EvaluationId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteMLModelInputTypeDef = TypedDict(
-    "DeleteMLModelInputTypeDef",
+DeleteMLModelInputRequestTypeDef = TypedDict(
+    "DeleteMLModelInputRequestTypeDef",
     {
         "MLModelId": str,
     },
 )
 
-DeleteMLModelOutputResponseTypeDef = TypedDict(
-    "DeleteMLModelOutputResponseTypeDef",
+DeleteMLModelOutputTypeDef = TypedDict(
+    "DeleteMLModelOutputTypeDef",
     {
         "MLModelId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteRealtimeEndpointInputTypeDef = TypedDict(
-    "DeleteRealtimeEndpointInputTypeDef",
+DeleteRealtimeEndpointInputRequestTypeDef = TypedDict(
+    "DeleteRealtimeEndpointInputRequestTypeDef",
     {
         "MLModelId": str,
     },
 )
 
-DeleteRealtimeEndpointOutputResponseTypeDef = TypedDict(
-    "DeleteRealtimeEndpointOutputResponseTypeDef",
+DeleteRealtimeEndpointOutputTypeDef = TypedDict(
+    "DeleteRealtimeEndpointOutputTypeDef",
     {
         "MLModelId": str,
         "RealtimeEndpointInfo": "RealtimeEndpointInfoTypeDef",
@@ -468,8 +471,8 @@ DeleteRealtimeEndpointOutputResponseTypeDef = TypedDict(
     },
 )
 
-DeleteTagsInputTypeDef = TypedDict(
-    "DeleteTagsInputTypeDef",
+DeleteTagsInputRequestTypeDef = TypedDict(
+    "DeleteTagsInputRequestTypeDef",
     {
         "TagKeys": List[str],
         "ResourceId": str,
@@ -477,8 +480,8 @@ DeleteTagsInputTypeDef = TypedDict(
     },
 )
 
-DeleteTagsOutputResponseTypeDef = TypedDict(
-    "DeleteTagsOutputResponseTypeDef",
+DeleteTagsOutputTypeDef = TypedDict(
+    "DeleteTagsOutputTypeDef",
     {
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
@@ -486,8 +489,8 @@ DeleteTagsOutputResponseTypeDef = TypedDict(
     },
 )
 
-DescribeBatchPredictionsInputTypeDef = TypedDict(
-    "DescribeBatchPredictionsInputTypeDef",
+DescribeBatchPredictionsInputRequestTypeDef = TypedDict(
+    "DescribeBatchPredictionsInputRequestTypeDef",
     {
         "FilterVariable": BatchPredictionFilterVariableType,
         "EQ": str,
@@ -504,8 +507,8 @@ DescribeBatchPredictionsInputTypeDef = TypedDict(
     total=False,
 )
 
-DescribeBatchPredictionsOutputResponseTypeDef = TypedDict(
-    "DescribeBatchPredictionsOutputResponseTypeDef",
+DescribeBatchPredictionsOutputTypeDef = TypedDict(
+    "DescribeBatchPredictionsOutputTypeDef",
     {
         "Results": List["BatchPredictionTypeDef"],
         "NextToken": str,
@@ -513,8 +516,8 @@ DescribeBatchPredictionsOutputResponseTypeDef = TypedDict(
     },
 )
 
-DescribeDataSourcesInputTypeDef = TypedDict(
-    "DescribeDataSourcesInputTypeDef",
+DescribeDataSourcesInputRequestTypeDef = TypedDict(
+    "DescribeDataSourcesInputRequestTypeDef",
     {
         "FilterVariable": DataSourceFilterVariableType,
         "EQ": str,
@@ -531,8 +534,8 @@ DescribeDataSourcesInputTypeDef = TypedDict(
     total=False,
 )
 
-DescribeDataSourcesOutputResponseTypeDef = TypedDict(
-    "DescribeDataSourcesOutputResponseTypeDef",
+DescribeDataSourcesOutputTypeDef = TypedDict(
+    "DescribeDataSourcesOutputTypeDef",
     {
         "Results": List["DataSourceTypeDef"],
         "NextToken": str,
@@ -540,8 +543,8 @@ DescribeDataSourcesOutputResponseTypeDef = TypedDict(
     },
 )
 
-DescribeEvaluationsInputTypeDef = TypedDict(
-    "DescribeEvaluationsInputTypeDef",
+DescribeEvaluationsInputRequestTypeDef = TypedDict(
+    "DescribeEvaluationsInputRequestTypeDef",
     {
         "FilterVariable": EvaluationFilterVariableType,
         "EQ": str,
@@ -558,8 +561,8 @@ DescribeEvaluationsInputTypeDef = TypedDict(
     total=False,
 )
 
-DescribeEvaluationsOutputResponseTypeDef = TypedDict(
-    "DescribeEvaluationsOutputResponseTypeDef",
+DescribeEvaluationsOutputTypeDef = TypedDict(
+    "DescribeEvaluationsOutputTypeDef",
     {
         "Results": List["EvaluationTypeDef"],
         "NextToken": str,
@@ -567,8 +570,8 @@ DescribeEvaluationsOutputResponseTypeDef = TypedDict(
     },
 )
 
-DescribeMLModelsInputTypeDef = TypedDict(
-    "DescribeMLModelsInputTypeDef",
+DescribeMLModelsInputRequestTypeDef = TypedDict(
+    "DescribeMLModelsInputRequestTypeDef",
     {
         "FilterVariable": MLModelFilterVariableType,
         "EQ": str,
@@ -585,8 +588,8 @@ DescribeMLModelsInputTypeDef = TypedDict(
     total=False,
 )
 
-DescribeMLModelsOutputResponseTypeDef = TypedDict(
-    "DescribeMLModelsOutputResponseTypeDef",
+DescribeMLModelsOutputTypeDef = TypedDict(
+    "DescribeMLModelsOutputTypeDef",
     {
         "Results": List["MLModelTypeDef"],
         "NextToken": str,
@@ -594,16 +597,16 @@ DescribeMLModelsOutputResponseTypeDef = TypedDict(
     },
 )
 
-DescribeTagsInputTypeDef = TypedDict(
-    "DescribeTagsInputTypeDef",
+DescribeTagsInputRequestTypeDef = TypedDict(
+    "DescribeTagsInputRequestTypeDef",
     {
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
     },
 )
 
-DescribeTagsOutputResponseTypeDef = TypedDict(
-    "DescribeTagsOutputResponseTypeDef",
+DescribeTagsOutputTypeDef = TypedDict(
+    "DescribeTagsOutputTypeDef",
     {
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
@@ -633,15 +636,15 @@ EvaluationTypeDef = TypedDict(
     total=False,
 )
 
-GetBatchPredictionInputTypeDef = TypedDict(
-    "GetBatchPredictionInputTypeDef",
+GetBatchPredictionInputRequestTypeDef = TypedDict(
+    "GetBatchPredictionInputRequestTypeDef",
     {
         "BatchPredictionId": str,
     },
 )
 
-GetBatchPredictionOutputResponseTypeDef = TypedDict(
-    "GetBatchPredictionOutputResponseTypeDef",
+GetBatchPredictionOutputTypeDef = TypedDict(
+    "GetBatchPredictionOutputTypeDef",
     {
         "BatchPredictionId": str,
         "MLModelId": str,
@@ -664,14 +667,14 @@ GetBatchPredictionOutputResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetDataSourceInputTypeDef = TypedDict(
-    "_RequiredGetDataSourceInputTypeDef",
+_RequiredGetDataSourceInputRequestTypeDef = TypedDict(
+    "_RequiredGetDataSourceInputRequestTypeDef",
     {
         "DataSourceId": str,
     },
 )
-_OptionalGetDataSourceInputTypeDef = TypedDict(
-    "_OptionalGetDataSourceInputTypeDef",
+_OptionalGetDataSourceInputRequestTypeDef = TypedDict(
+    "_OptionalGetDataSourceInputRequestTypeDef",
     {
         "Verbose": bool,
     },
@@ -679,14 +682,14 @@ _OptionalGetDataSourceInputTypeDef = TypedDict(
 )
 
 
-class GetDataSourceInputTypeDef(
-    _RequiredGetDataSourceInputTypeDef, _OptionalGetDataSourceInputTypeDef
+class GetDataSourceInputRequestTypeDef(
+    _RequiredGetDataSourceInputRequestTypeDef, _OptionalGetDataSourceInputRequestTypeDef
 ):
     pass
 
 
-GetDataSourceOutputResponseTypeDef = TypedDict(
-    "GetDataSourceOutputResponseTypeDef",
+GetDataSourceOutputTypeDef = TypedDict(
+    "GetDataSourceOutputTypeDef",
     {
         "DataSourceId": str,
         "DataLocationS3": str,
@@ -712,15 +715,15 @@ GetDataSourceOutputResponseTypeDef = TypedDict(
     },
 )
 
-GetEvaluationInputTypeDef = TypedDict(
-    "GetEvaluationInputTypeDef",
+GetEvaluationInputRequestTypeDef = TypedDict(
+    "GetEvaluationInputRequestTypeDef",
     {
         "EvaluationId": str,
     },
 )
 
-GetEvaluationOutputResponseTypeDef = TypedDict(
-    "GetEvaluationOutputResponseTypeDef",
+GetEvaluationOutputTypeDef = TypedDict(
+    "GetEvaluationOutputTypeDef",
     {
         "EvaluationId": str,
         "MLModelId": str,
@@ -741,14 +744,14 @@ GetEvaluationOutputResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetMLModelInputTypeDef = TypedDict(
-    "_RequiredGetMLModelInputTypeDef",
+_RequiredGetMLModelInputRequestTypeDef = TypedDict(
+    "_RequiredGetMLModelInputRequestTypeDef",
     {
         "MLModelId": str,
     },
 )
-_OptionalGetMLModelInputTypeDef = TypedDict(
-    "_OptionalGetMLModelInputTypeDef",
+_OptionalGetMLModelInputRequestTypeDef = TypedDict(
+    "_OptionalGetMLModelInputRequestTypeDef",
     {
         "Verbose": bool,
     },
@@ -756,12 +759,14 @@ _OptionalGetMLModelInputTypeDef = TypedDict(
 )
 
 
-class GetMLModelInputTypeDef(_RequiredGetMLModelInputTypeDef, _OptionalGetMLModelInputTypeDef):
+class GetMLModelInputRequestTypeDef(
+    _RequiredGetMLModelInputRequestTypeDef, _OptionalGetMLModelInputRequestTypeDef
+):
     pass
 
 
-GetMLModelOutputResponseTypeDef = TypedDict(
-    "GetMLModelOutputResponseTypeDef",
+GetMLModelOutputTypeDef = TypedDict(
+    "GetMLModelOutputTypeDef",
     {
         "MLModelId": str,
         "TrainingDataSourceId": str,
@@ -832,8 +837,8 @@ PerformanceMetricsTypeDef = TypedDict(
     total=False,
 )
 
-PredictInputTypeDef = TypedDict(
-    "PredictInputTypeDef",
+PredictInputRequestTypeDef = TypedDict(
+    "PredictInputRequestTypeDef",
     {
         "MLModelId": str,
         "Record": Dict[str, str],
@@ -841,8 +846,8 @@ PredictInputTypeDef = TypedDict(
     },
 )
 
-PredictOutputResponseTypeDef = TypedDict(
-    "PredictOutputResponseTypeDef",
+PredictOutputTypeDef = TypedDict(
+    "PredictOutputTypeDef",
     {
         "Prediction": "PredictionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1019,62 +1024,62 @@ TagTypeDef = TypedDict(
     total=False,
 )
 
-UpdateBatchPredictionInputTypeDef = TypedDict(
-    "UpdateBatchPredictionInputTypeDef",
+UpdateBatchPredictionInputRequestTypeDef = TypedDict(
+    "UpdateBatchPredictionInputRequestTypeDef",
     {
         "BatchPredictionId": str,
         "BatchPredictionName": str,
     },
 )
 
-UpdateBatchPredictionOutputResponseTypeDef = TypedDict(
-    "UpdateBatchPredictionOutputResponseTypeDef",
+UpdateBatchPredictionOutputTypeDef = TypedDict(
+    "UpdateBatchPredictionOutputTypeDef",
     {
         "BatchPredictionId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-UpdateDataSourceInputTypeDef = TypedDict(
-    "UpdateDataSourceInputTypeDef",
+UpdateDataSourceInputRequestTypeDef = TypedDict(
+    "UpdateDataSourceInputRequestTypeDef",
     {
         "DataSourceId": str,
         "DataSourceName": str,
     },
 )
 
-UpdateDataSourceOutputResponseTypeDef = TypedDict(
-    "UpdateDataSourceOutputResponseTypeDef",
+UpdateDataSourceOutputTypeDef = TypedDict(
+    "UpdateDataSourceOutputTypeDef",
     {
         "DataSourceId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-UpdateEvaluationInputTypeDef = TypedDict(
-    "UpdateEvaluationInputTypeDef",
+UpdateEvaluationInputRequestTypeDef = TypedDict(
+    "UpdateEvaluationInputRequestTypeDef",
     {
         "EvaluationId": str,
         "EvaluationName": str,
     },
 )
 
-UpdateEvaluationOutputResponseTypeDef = TypedDict(
-    "UpdateEvaluationOutputResponseTypeDef",
+UpdateEvaluationOutputTypeDef = TypedDict(
+    "UpdateEvaluationOutputTypeDef",
     {
         "EvaluationId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredUpdateMLModelInputTypeDef = TypedDict(
-    "_RequiredUpdateMLModelInputTypeDef",
+_RequiredUpdateMLModelInputRequestTypeDef = TypedDict(
+    "_RequiredUpdateMLModelInputRequestTypeDef",
     {
         "MLModelId": str,
     },
 )
-_OptionalUpdateMLModelInputTypeDef = TypedDict(
-    "_OptionalUpdateMLModelInputTypeDef",
+_OptionalUpdateMLModelInputRequestTypeDef = TypedDict(
+    "_OptionalUpdateMLModelInputRequestTypeDef",
     {
         "MLModelName": str,
         "ScoreThreshold": float,
@@ -1083,14 +1088,14 @@ _OptionalUpdateMLModelInputTypeDef = TypedDict(
 )
 
 
-class UpdateMLModelInputTypeDef(
-    _RequiredUpdateMLModelInputTypeDef, _OptionalUpdateMLModelInputTypeDef
+class UpdateMLModelInputRequestTypeDef(
+    _RequiredUpdateMLModelInputRequestTypeDef, _OptionalUpdateMLModelInputRequestTypeDef
 ):
     pass
 
 
-UpdateMLModelOutputResponseTypeDef = TypedDict(
-    "UpdateMLModelOutputResponseTypeDef",
+UpdateMLModelOutputTypeDef = TypedDict(
+    "UpdateMLModelOutputTypeDef",
     {
         "MLModelId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
